Stan Math Library: stan/math/fwd/scal/fun/inv_Phi.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_Phi.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_INV_PHI_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_INV_PHI_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/inv_Phi.hpp>
7 #include <stan/math/prim/scal/fun/constants.hpp>
8 #include <stan/math/prim/scal/fun/square.hpp>
9
10 namespace stan {
11
12 namespace math {
13
14 template <typename T>
15 inline fvar<T> inv_Phi(const fvar<T>& p) {
16 using stan::math::inv_Phi;
17 using std::exp;
18 T xv = inv_Phi(p.val_);
19 return fvar<T>(xv,
20 p.d_ / exp(-0.5 * square(xv)) * SQRT_2_TIMES_SQRT_PI);
21 }
22 }
23 }
24 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::inv_Phi
fvar< T > inv_Phi(const fvar< T > &p)
Definition: inv_Phi.hpp:15
stan
Definition: log_sum_exp.hpp:8
square.hpp
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::SQRT_2_TIMES_SQRT_PI
const double SQRT_2_TIMES_SQRT_PI
Definition: constants.hpp:158
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
constants.hpp
inv_Phi.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.